@@ -10,14 +10,15 @@ build_time_vars = {'ABIFLAGS': '',
  'ANDROID_API_LEVEL': 0,
  'AR': 'ar',
  'ARFLAGS': 'rcs',
- 'BASECFLAGS': '-fno-strict-overflow',
+ 'BASECFLAGS': '-fno-strict-overflow -Wsign-compare',
  'BASECPPFLAGS': '',
  'BASEMODLIBS': '',
  'BINDIR': '/usr/bin',
  'BINLIBDEST': '/usr/lib/python3.12',
  'BLDLIBRARY': '-L. -lpython3.12',
- 'BLDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-              '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'BLDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+              '-Wl,-z,relro -Wl,-z,now -Wl,-O1 -Wl,--sort-common '
+              '-Wl,--as-needed -Wl,-z,relro -Wl,-z,now',
  'BOOTSTRAP_HEADERS': '\\',
  'BUILDEXE': '',
  'BUILDPYTHON': 'python',
@@ -26,8 +27,8 @@ build_time_vars = {'ABIFLAGS': '',
  'BYTESTR_DEPS': '\\',
  'CC': 'gcc',
  'CCSHARED': '-fPIC',
- 'CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv7-a '
-           '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
+ 'CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+           '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
            '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
            '-Werror=format-security         -fstack-clash-protection '
            '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
@@ -48,10 +49,14 @@ build_time_vars = {'ABIFLAGS': '',
                      '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                      '-Wformat -Werror=format-security         '
                      '-fstack-clash-protection',
- 'CONFIGURE_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration '
+ 'CONFIGURE_CFLAGS_NODIST': '-std=c11 -Wextra -Wno-unused-parameter '
+                            '-Wno-missing-field-initializers '
+                            '-Wstrict-prototypes '
+                            '-Werror=implicit-function-declaration '
                             '-fvisibility=hidden',
  'CONFIGURE_CPPFLAGS': '',
- 'CONFIGURE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'CONFIGURE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                      '-Wl,-z,now',
  'CONFIGURE_LDFLAGS_NODIST': '',
  'CONFIGURE_LDFLAGS_NOLTO': '',
  'CONFIG_ARGS': "'--prefix=/usr' '--enable-shared' '--with-computed-gotos' "
@@ -62,14 +67,14 @@ build_time_vars = {'ABIFLAGS': '',
                 '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
                 '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                 "-Werror=format-security         -fstack-clash-protection' "
-                "'LDFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now' "
-                "'CPPFLAGS='",
+                "'LDFLAGS=-Wl,-O1 -Wl,--sort-common -Wl,--as-needed "
+                "-Wl,-z,relro -Wl,-z,now' 'CPPFLAGS='",
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.12',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/build/python/src/Python-3.12.4/coverage.info',
+ 'COVERAGE_INFO': '/build/python/src/Python-3.12.5/coverage.info',
  'COVERAGE_LCOV_OPTIONS': '--rc lcov_branch_coverage=1',
- 'COVERAGE_REPORT': '/build/python/src/Python-3.12.4/lcov-report',
+ 'COVERAGE_REPORT': '/build/python/src/Python-3.12.5/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--rc lcov_branch_coverage=1 --branch-coverage '
                             '--title "CPython 3.12 LCOV report [commit $(shell '
                             ')]"',
@@ -628,19 +633,62 @@ build_time_vars = {'ABIFLAGS': '',
  'IO_H': 'Modules/_io/_iomodule.h',
  'IO_OBJS': '\\',
  'LDCXXSHARED': 'g++ -shared',
- 'LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-            '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now '
+            '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro -Wl,-z,now',
  'LDFLAGS_NODIST': '',
  'LDLIBRARY': 'libpython3.12.so',
  'LDLIBRARYDIR': '',
- 'LDSHARED': 'gcc -shared -Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-             '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'LDSHARED': 'gcc -shared -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+             '-Wl,-z,relro -Wl,-z,now -Wl,-O1 -Wl,--sort-common '
+             '-Wl,--as-needed -Wl,-z,relro -Wl,-z,now',
  'LDVERSION': '3.12',
  'LIBC': '',
  'LIBDEST': '/usr/lib/python3.12',
  'LIBDIR': '/usr/lib',
  'LIBEXPAT_A': 'Modules/expat/libexpat.a',
- 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv7-a '
+ 'LIBEXPAT_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+                    '-Wformat -Werror=format-security         '
+                    '-fstack-clash-protection -march=armv7-a -mfloat-abi=hard '
+                    '-mfpu=neon -O3 -pipe -fno-plt -fexceptions         '
+                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                    '-Werror=format-security         -fstack-clash-protection '
+                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+                    '-Wformat -Werror=format-security         '
+                    '-fstack-clash-protection -std=c11 -Wextra '
+                    '-Wno-unused-parameter -Wno-missing-field-initializers '
+                    '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                    '-fPIC -fPIC',
+ 'LIBEXPAT_HEADERS': '\\',
+ 'LIBEXPAT_OBJS': '\\',
+ 'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
+                   '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+                   '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                   '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+                   '-Wformat -Werror=format-security         '
+                   '-fstack-clash-protection -march=armv7-a -mfloat-abi=hard '
+                   '-mfpu=neon -O3 -pipe -fno-plt -fexceptions         '
+                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                   '-Werror=format-security         -fstack-clash-protection '
+                   '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                   '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+                   '-Wformat -Werror=format-security         '
+                   '-fstack-clash-protection -std=c11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
+                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
+                   '-fPIC -fPIC',
+ 'LIBHACL_HEADERS': '\\',
+ 'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
+ 'LIBHACL_SHA2_HEADERS': '\\',
+ 'LIBHACL_SHA2_OBJS': '\\',
+ 'LIBM': '-lm',
+ 'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
+ 'LIBMPDEC_CFLAGS': '-DCONFIG_32=1 -DANSI=1 -fno-strict-overflow '
+                    '-Wsign-compare -DNDEBUG -g -O3 -Wall -march=armv7-a '
                     '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
                     '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
@@ -651,45 +699,9 @@ build_time_vars = {'ABIFLAGS': '',
                     '-mfpu=neon -O3 -pipe -fno-plt -fexceptions         '
                     '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                     '-Werror=format-security         -fstack-clash-protection '
-                    '-std=c11 -Werror=implicit-function-declaration '
-                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                    '-fPIC -fPIC',
- 'LIBEXPAT_HEADERS': '\\',
- 'LIBEXPAT_OBJS': '\\',
- 'LIBHACL_CFLAGS': '-I./Modules/_hacl/include -D_BSD_SOURCE -D_DEFAULT_SOURCE '
-                   '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
-                   '-Werror=format-security         -fstack-clash-protection '
-                   '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
-                   '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
-                   '-Wformat -Werror=format-security         '
-                   '-fstack-clash-protection -march=armv7-a -mfloat-abi=hard '
-                   '-mfpu=neon -O3 -pipe -fno-plt -fexceptions         '
-                   '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
-                   '-Werror=format-security         -fstack-clash-protection '
-                   '-std=c11 -Werror=implicit-function-declaration '
-                   '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
-                   '-fPIC -fPIC',
- 'LIBHACL_HEADERS': '\\',
- 'LIBHACL_SHA2_A': 'Modules/_hacl/libHacl_Hash_SHA2.a',
- 'LIBHACL_SHA2_HEADERS': '\\',
- 'LIBHACL_SHA2_OBJS': '\\',
- 'LIBM': '-lm',
- 'LIBMPDEC_A': 'Modules/_decimal/libmpdec/libmpdec.a',
- 'LIBMPDEC_CFLAGS': '-DCONFIG_32=1 -DANSI=1 -fno-strict-overflow -DNDEBUG -g '
-                    '-O3 -Wall -march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
-                    '-pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
-                    '-Werror=format-security         -fstack-clash-protection '
-                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
-                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
-                    '-Wformat -Werror=format-security         '
-                    '-fstack-clash-protection -march=armv7-a -mfloat-abi=hard '
-                    '-mfpu=neon -O3 -pipe -fno-plt -fexceptions         '
-                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
-                    '-Werror=format-security         -fstack-clash-protection '
-                    '-std=c11 -Werror=implicit-function-declaration '
+                    '-std=c11 -Wextra -Wno-unused-parameter '
+                    '-Wno-missing-field-initializers -Wstrict-prototypes '
+                    '-Werror=implicit-function-declaration '
                     '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                     '-fPIC -fPIC',
  'LIBMPDEC_HEADERS': '\\',
@@ -1054,11 +1066,11 @@ build_time_vars = {'ABIFLAGS': '',
  'PYTHON_HEADERS': '\\',
  'PYTHON_OBJS': '\\',
  'PY_BUILTIN_HASHLIB_HASHES': '"md5,sha1,sha2,sha3,blake2"',
- 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall '
-                             '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
-                             '-pipe -fno-plt -fexceptions         '
-                             '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
-                             '-Werror=format-security         '
+ 'PY_BUILTIN_MODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g '
+                             '-O3 -Wall -march=armv7-a -mfloat-abi=hard '
+                             '-mfpu=neon -O3 -pipe -fno-plt '
+                             '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+                             '-Wformat -Werror=format-security         '
                              '-fstack-clash-protection -march=armv7-a '
                              '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
@@ -1067,12 +1079,15 @@ build_time_vars = {'ABIFLAGS': '',
                              '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
                              '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                              '-Wformat -Werror=format-security         '
-                             '-fstack-clash-protection -std=c11 '
+                             '-fstack-clash-protection -std=c11 -Wextra '
+                             '-Wno-unused-parameter '
+                             '-Wno-missing-field-initializers '
+                             '-Wstrict-prototypes '
                              '-Werror=implicit-function-declaration '
                              '-fvisibility=hidden  -I./Include/internal -I. '
                              '-I./Include -fPIC -DPy_BUILD_CORE_BUILTIN',
- 'PY_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv7-a '
-              '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
+ 'PY_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
+              '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
               '-Werror=format-security         -fstack-clash-protection '
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
@@ -1081,13 +1096,12 @@ build_time_vars = {'ABIFLAGS': '',
               '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
               '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
               '-Werror=format-security         -fstack-clash-protection',
- 'PY_CFLAGS_NODIST': '-std=c11 -Werror=implicit-function-declaration '
+ 'PY_CFLAGS_NODIST': '-std=c11 -Wextra -Wno-unused-parameter '
+                     '-Wno-missing-field-initializers -Wstrict-prototypes '
+                     '-Werror=implicit-function-declaration '
                      '-fvisibility=hidden  -I./Include/internal',
  'PY_COERCE_C_LOCALE': 1,
- 'PY_CORE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall -march=armv7-a '
-                   '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
-                   '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
-                   '-Werror=format-security         -fstack-clash-protection '
+ 'PY_CORE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 -Wall '
                    '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
                    '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
                    '-Wformat -Werror=format-security         '
@@ -1095,27 +1109,36 @@ build_time_vars = {'ABIFLAGS': '',
                    '-mfpu=neon -O3 -pipe -fno-plt -fexceptions         '
                    '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                    '-Werror=format-security         -fstack-clash-protection '
-                   '-std=c11 -Werror=implicit-function-declaration '
+                   '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
+                   '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
+                   '-Wformat -Werror=format-security         '
+                   '-fstack-clash-protection -std=c11 -Wextra '
+                   '-Wno-unused-parameter -Wno-missing-field-initializers '
+                   '-Wstrict-prototypes -Werror=implicit-function-declaration '
                    '-fvisibility=hidden  -I./Include/internal -I. -I./Include '
                    '-fPIC -DPy_BUILD_CORE',
- 'PY_CORE_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                    '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'PY_CORE_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                    '-Wl,-z,now -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+                    '-Wl,-z,relro -Wl,-z,now',
  'PY_CPPFLAGS': '-I. -I./Include',
  'PY_ENABLE_SHARED': 1,
  'PY_HAVE_PERF_TRAMPOLINE': 0,
- 'PY_LDFLAGS': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-               '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'PY_LDFLAGS': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+               '-Wl,-z,now -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+               '-Wl,-z,relro -Wl,-z,now',
  'PY_LDFLAGS_NODIST': '',
- 'PY_LDFLAGS_NOLTO': '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now '
-                     '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
+ 'PY_LDFLAGS_NOLTO': '-Wl,-O1 -Wl,--sort-common -Wl,--as-needed -Wl,-z,relro '
+                     '-Wl,-z,now -Wl,-O1 -Wl,--sort-common -Wl,--as-needed '
+                     '-Wl,-z,relro -Wl,-z,now',
  'PY_SQLITE_ENABLE_LOAD_EXTENSION': 1,
  'PY_SQLITE_HAVE_SERIALIZE': 1,
  'PY_SSL_DEFAULT_CIPHERS': 1,
  'PY_SSL_DEFAULT_CIPHER_STRING': 0,
- 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -DNDEBUG -g -O3 -Wall '
-                        '-march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 -pipe '
-                        '-fno-plt -fexceptions         -Wp,-D_FORTIFY_SOURCE=3 '
-                        '-Wformat -Werror=format-security         '
+ 'PY_STDMODULE_CFLAGS': '-fno-strict-overflow -Wsign-compare -DNDEBUG -g -O3 '
+                        '-Wall -march=armv7-a -mfloat-abi=hard -mfpu=neon -O3 '
+                        '-pipe -fno-plt -fexceptions         '
+                        '-Wp,-D_FORTIFY_SOURCE=3 -Wformat '
+                        '-Werror=format-security         '
                         '-fstack-clash-protection -march=armv7-a '
                         '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
@@ -1124,7 +1147,9 @@ build_time_vars = {'ABIFLAGS': '',
                         '-mfloat-abi=hard -mfpu=neon -O3 -pipe -fno-plt '
                         '-fexceptions         -Wp,-D_FORTIFY_SOURCE=3 -Wformat '
                         '-Werror=format-security         '
-                        '-fstack-clash-protection -std=c11 '
+                        '-fstack-clash-protection -std=c11 -Wextra '
+                        '-Wno-unused-parameter -Wno-missing-field-initializers '
+                        '-Wstrict-prototypes '
                         '-Werror=implicit-function-declaration '
                         '-fvisibility=hidden  -I./Include/internal -I. '
                         '-I./Include -fPIC',
@@ -1139,7 +1164,7 @@ build_time_vars = {'ABIFLAGS': '',
  'READELF': '@READELF@',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.5',
  'SCRIPTDIR': '/usr/lib',
  'SCRIPT_2TO3': 'build/scripts-3.12/2to3-3.12',
  'SCRIPT_IDLE': 'build/scripts-3.12/idle3.12',
@@ -1265,9 +1290,9 @@ build_time_vars = {'ABIFLAGS': '',
  'SYS_SELECT_WITH_SYS_TIME': 1,
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4 ./python -E',
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.5 ./python -E',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.4 ./python -E '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/build/python/src/Python-3.12.5 ./python -E '
                './Tools/scripts/run_tests.py',
  'TESTSUBDIRS': 'idlelib/idle_test \\',
  'TESTTIMEOUT': 1200,
@@ -1297,8 +1322,8 @@ build_time_vars = {'ABIFLAGS': '',
  'WITH_VALGRIND': 0,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/build/python/src/Python-3.12.4',
- 'abs_srcdir': '/build/python/src/Python-3.12.4',
+ 'abs_builddir': '/build/python/src/Python-3.12.5',
+ 'abs_srcdir': '/build/python/src/Python-3.12.5',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
